@@ -39,12 +39,8 @@ static void
 cb_do_popup (GtkWindow *window, BonoboWindow *win)
 {
 	GtkWidget *menu;
-	GtkWidget *menuitem;
 
 	menu = gtk_menu_new ();
-	menuitem = gtk_menu_item_new_with_label ("Is anything else here yet ?");
-	gtk_widget_show (menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
 
 	bonobo_window_add_popup (win, GTK_MENU (menu), "/popups/MyStuff");
 
@@ -175,7 +171,7 @@ main (int argc, char **argv)
 		"	</submenu>\n"
 		"</menu>";
 	char simpleb [] =
-		"<submenu name=\"File\">\n"
+		"<submenu name=\"File\" _label=\"_File\">\n"
 		"	<menuitem name=\"open\" _label=\"_OpenB\" pixtype=\"stock\" pixname=\"Open\" _tip=\"Open you fool\"/>\n"
 		"       <separator/>\n"
 		"       <menuitem name=\"toggle\" type=\"toggle\" id=\"MyFoo\" _label=\"_ToggleMe\" _tip=\"a\" accel=\"*Control*t\"/>\n"
@@ -185,7 +181,7 @@ main (int argc, char **argv)
 		"</submenu>\n";
 	char simplec [] =
 		"<submenu name=\"File\" _label=\"_FileC\" _tip=\"what!\">\n"
-		"    <placeholder name=\"Nice\" delimit=\"top\">\n"
+		"    <placeholder name=\"Nice\" delimit=\"top\" hidden=\"1\">\n"
 		"	<menuitem name=\"fooa\" _label=\"_FooA\" type=\"radio\" group=\"foogroup\" _tip=\"Radio1\"/>\n"
 		"	<menuitem name=\"foob\" _label=\"_FooB\" type=\"radio\" group=\"foogroup\" _tip=\"kippers\"/>\n"
 		"	<menuitem name=\"wibble\" verb=\"ThisForcesAnError\" _label=\"_Baa\""
@@ -426,6 +422,7 @@ main (int argc, char **argv)
 	bonobo_ui_component_set_status (componenta, "WhatA1", &ev);
 	bonobo_ui_component_set_status (componentb, "WhatB2", &ev);
 	bonobo_ui_component_set_status (componenta, "WhatA3", &ev);
+	bonobo_ui_component_rm (componenta, "/status", &ev);
 	bonobo_ui_component_set_status (componentb, "WhatB4", &ev);
 	bonobo_ui_component_set_status (componenta, "WhatA5", &ev);
 	bonobo_ui_component_set_status (componenta, "WhatA6", &ev);
