@@ -27,12 +27,11 @@ BEGIN_GNOME_DECLS
 #define BONOBO_IS_CONTROL_FRAME_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_CONTROL_FRAME_TYPE))
 
 typedef struct _BonoboControlFramePrivate BonoboControlFramePrivate;
-typedef struct _BonoboControlFrame BonoboControlFrame;
 
-struct _BonoboControlFrame {
+typedef struct {
 	BonoboObject base;
 	BonoboControlFramePrivate *priv;
-};
+} BonoboControlFrame;
 
 typedef struct {
 	BonoboObjectClass parent_class;
@@ -103,6 +102,10 @@ POA_Bonobo_ControlFrame__epv *bonobo_control_frame_get_epv                   (vo
 void  bonobo_control_frame_size_request (BonoboControlFrame *control_frame,
 					int *desired_width,
 					int *desired_height);
+
+/* You almost certainly don't want these methods */
+void  bonobo_control_frame_sync_realize   (BonoboControlFrame *frame);
+void  bonobo_control_frame_sync_unrealize (BonoboControlFrame *frame);
     
 END_GNOME_DECLS
 
