@@ -200,7 +200,7 @@ bonobo_object_client_query_interface (BonoboObjectClient *object,
 						   bonobo_object_corba_objref (BONOBO_OBJECT (object)),
 						   interface_desc, ev);
 	
-        if (ev->_major != CORBA_NO_EXCEPTION) {
+        if (BONOBO_EX(ev)) {
 		bonobo_object_check_env (BONOBO_OBJECT (object),
 					bonobo_object_corba_objref (BONOBO_OBJECT (object)),
 					ev);
@@ -252,7 +252,7 @@ bonobo_object_client_has_interface (BonoboObjectClient *object,
 
 		Bonobo_Unknown_unref  (interface, ev);
 
-		if (ev->_major != CORBA_NO_EXCEPTION) {
+		if (BONOBO_EX(ev)) {
 			bonobo_object_check_env (BONOBO_OBJECT (object),
 						bonobo_object_corba_objref (BONOBO_OBJECT (object)),
 						ev);
@@ -263,7 +263,7 @@ bonobo_object_client_has_interface (BonoboObjectClient *object,
 
 		CORBA_Object_release (interface, ev);
 
-		if (ev->_major != CORBA_NO_EXCEPTION) {
+		if (BONOBO_EX(ev)) {
 			bonobo_object_check_env (BONOBO_OBJECT (object),
 						bonobo_object_corba_objref (BONOBO_OBJECT (object)),
 						ev);
@@ -294,7 +294,7 @@ bonobo_object_client_ref (BonoboObjectClient *object_client,
 
 	Bonobo_Unknown_ref (object->corba_objref, &ev);
 
-	if (ev._major != CORBA_NO_EXCEPTION) {
+	if (BONOBO_EX (&ev)) {
 		CORBA_exception_free (&ev);
 		bonobo_object_check_env (opt_exception_obj?opt_exception_obj:object,
 					 object->corba_objref, &ev);
@@ -318,7 +318,7 @@ bonobo_object_client_unref (BonoboObjectClient *object_client,
 
 	Bonobo_Unknown_unref (object->corba_objref, &ev);
 
-	if (ev._major != CORBA_NO_EXCEPTION) {
+	if (BONOBO_EX (&ev)) {
 		CORBA_exception_free (&ev);
 		bonobo_object_check_env (opt_exception_obj?opt_exception_obj:object,
 					 object->corba_objref, &ev);
