@@ -11,6 +11,7 @@
 #include <config.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmarshal.h>
+#include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-persist-file.h>
 
 /* Parent GTK object class */
@@ -232,7 +233,7 @@ create_bonobo_persist_file (BonoboObject *object)
 	servant->vepv = &bonobo_persist_file_vepv;
 	CORBA_exception_init (&ev);
 	POA_Bonobo_PersistFile__init ((PortableServer_Servant) servant, &ev);
-	if (ev._major != CORBA_NO_EXCEPTION){
+	if (BONOBO_EX (&ev)){
 		g_free (servant);
 		CORBA_exception_free (&ev);
 		return CORBA_OBJECT_NIL;
