@@ -18,19 +18,16 @@
 #define BONOBO_IS_UI_CONTAINER(o)       (GTK_CHECK_TYPE ((o), BONOBO_UI_CONTAINER_TYPE))
 #define BONOBO_IS_UI_CONTAINER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_UI_CONTAINER_TYPE))
 
-typedef struct _BonoboUIContainer        BonoboUIContainer;
-typedef struct _BonoboUIContainerClass   BonoboUIContainerClass;
-
-struct _BonoboUIContainer {
+typedef struct {
 	BonoboObject base;
 
 	int          flags;
 	BonoboWindow   *win;
-};
+} BonoboUIContainer;
 
-struct _BonoboUIContainerClass {
+typedef struct {
 	BonoboObjectClass parent;
-};
+} BonoboUIContainerClass;
 
 GtkType                      bonobo_ui_container_get_type            (void);
 POA_Bonobo_UIContainer__epv *bonobo_ui_container_get_epv             (void);
@@ -41,6 +38,7 @@ BonoboUIContainer           *bonobo_ui_container_construct           (BonoboUICo
 BonoboUIContainer           *bonobo_ui_container_new                 (void);
 
 void                         bonobo_ui_container_set_win             (BonoboUIContainer  *container,
-								      BonoboWindow          *win);
+								      BonoboWindow       *win);
+BonoboWindow                *bonobo_ui_container_get_win             (BonoboUIContainer  *container);
 
 #endif /* _BONOBO_UI_CONTAINER_H_ */
