@@ -564,7 +564,7 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 
 	/* first, make a pass through the items to layout the ones that are packed on the right */
 	priv->end_position = allocation->x + available_space;
-	for (p = priv->items; p != NULL; p = p->next) {
+	for (p = g_list_last (priv->items); p != NULL; p = p->prev) {
 
 		item = BONOBO_UI_TOOLBAR_ITEM (p->data);
 		if (! bonobo_ui_toolbar_item_get_pack_end (item))
@@ -692,20 +692,19 @@ impl_destroy (GtkObject *object)
 {
 	BonoboUIToolbar *toolbar;
 	BonoboUIToolbarPrivate *priv;
-	GList *p;
+	GList *p, *next;
 
 	toolbar = BONOBO_UI_TOOLBAR (object);
 	priv = toolbar->priv;
 
-	for (p = priv->items; p != NULL; p = p->next) {
+	for (p = priv->items; p != NULL; p = next) {
 		GtkWidget *item_widget;
 
+		next = p->next;
 		item_widget = GTK_WIDGET (p->data);
 		if (item_widget->parent == NULL)
 			gtk_widget_destroy (item_widget);
 	}
-	g_list_free (priv->items);
-	priv->items = NULL;
 
 	if (GTK_WIDGET (priv->popup_item)->parent == NULL)
 		gtk_widget_destroy (GTK_WIDGET (priv->popup_item));
@@ -718,8 +717,23 @@ impl_destroy (GtkObject *object)
 	priv->tooltips = NULL;
 
 	if (GTK_OBJECT_CLASS (parent_class)->destroy != NULL)
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+		GTK_OBJECT_CLASS (parent_class)->destroy (object);
 
+}
+
+static void
+impl_finalize (GtkObject *object)
+{
+	BonoboUIToolbar *toolbar;
+	BonoboUIToolbarPrivate *priv;
+	GList *p;
+
+	toolbar = BONOBO_UI_TOOLBAR (object);
+	priv = toolbar->priv;
+
+	g_list_free (priv->items);
+	priv->items = NULL;
+	
 	g_free (priv);
 }
 
@@ -906,7 +920,7 @@ impl_expose_event (GtkWidget *widget,
 
 static void
 impl_remove (GtkContainer *container,
-	     GtkWidget *child)
+	     GtkWidget    *child)
 {
 	BonoboUIToolbar *toolbar;
 	BonoboUIToolbarPrivate *priv;
@@ -1026,12 +1040,14 @@ impl_get_arg (GtkObject *obj,
 		GTK_VALUE_BOOL (*arg) = priv->is_floating;
 		break;
 	case ARG_PREFERRED_WIDTH:
+		update_sizes (toolbar);
 		if (bonobo_ui_toolbar_get_orientation (toolbar) == GTK_ORIENTATION_HORIZONTAL)
 			GTK_VALUE_UINT (*arg) = priv->total_width;
 		else
 			GTK_VALUE_UINT (*arg) = priv->max_width;
 		break;
 	case ARG_PREFERRED_HEIGHT:
+		update_sizes (toolbar);
 		if (bonobo_ui_toolbar_get_orientation (toolbar) == GTK_ORIENTATION_HORIZONTAL)
 			GTK_VALUE_UINT (*arg) = priv->max_height;
 		else
@@ -1070,9 +1086,10 @@ class_init (BonoboUIToolbarClass *toolbar_class)
 	GtkContainerClass *container_class;
 
 	object_class = GTK_OBJECT_CLASS (toolbar_class);
-	object_class->destroy = impl_destroy;
-	object_class->get_arg = impl_get_arg;
-	object_class->set_arg = impl_set_arg;
+	object_class->destroy  = impl_destroy;
+	object_class->finalize = impl_finalize;
+	object_class->get_arg  = impl_get_arg;
+	object_class->set_arg  = impl_set_arg;
 
 	widget_class = GTK_WIDGET_CLASS (toolbar_class);
 	widget_class->size_request  = impl_size_request;
