@@ -90,7 +90,7 @@ do_strip (xmlNode *node)
 			do_strip (a->val);
 		}
 
-		for (l = node->childs; l; l = next) {
+		for (l = node->xmlChildrenNode; l; l = next) {
 			next = l->next;
 			do_strip (l);
 		}
@@ -144,8 +144,10 @@ bonobo_ui_xml_get_data (BonoboUIXml *tree, BonoboUINode *node)
 	if (!bonobo_ui_node_get_data (node)) {
 		if (tree && tree->data_new)
 			bonobo_ui_node_set_data (node, tree->data_new ());
-		else
+		else {
+			g_warning ("Error: No tree, and no data on node; leaking");
 			bonobo_ui_node_set_data (node, g_new0 (BonoboUIXmlData, 1));
+		}
 	}
 
 	return bonobo_ui_node_get_data (node);
@@ -255,14 +257,6 @@ free_nodedata (BonoboUIXml *tree, BonoboUIXmlData *data,
 	}
 }
 
-static void
-node_free (BonoboUIXml *tree, BonoboUINode *node)
-{
-	free_nodedata (tree, bonobo_ui_node_get_data (node), FALSE);
-	bonobo_ui_node_unlink (node);
-	bonobo_ui_node_free (node);
-}
-
 static void
 free_nodedata_tree (BonoboUIXml *tree, BonoboUINode *node, gboolean do_overrides)
 {
@@ -274,10 +268,18 @@ free_nodedata_tree (BonoboUIXml *tree, BonoboUINode *node, gboolean do_overrides
 	free_nodedata (tree, bonobo_ui_node_get_data (node), do_overrides);
 
 	for (l = bonobo_ui_node_children (node); l;
-             l = bonobo_ui_node_next (l));
+             l = bonobo_ui_node_next (l))
 		free_nodedata_tree (tree, l, do_overrides);
 }
 
+static void
+node_free (BonoboUIXml *tree, BonoboUINode *node)
+{
+	free_nodedata_tree (tree, node, TRUE);
+	bonobo_ui_node_unlink (node);
+	bonobo_ui_node_free (node);
+}
+
 static void
 do_set_id (BonoboUIXml *tree, BonoboUINode *node, gpointer id)
 {
@@ -372,13 +374,13 @@ bonobo_ui_xml_dump (BonoboUIXml *tree, BonoboUINode *bnode, const char *descr)
         xmlNode *node = XML_NODE (bnode);
 
 	doc = xmlNewDoc ("1.0");
-	doc->root = node;
+	doc->xmlRootNode = node;
 	
 	fprintf (stderr, "%s\n", descr);
 
 	xmlDocDump (stderr, doc);
 
-	doc->root = NULL;
+	doc->xmlRootNode = NULL;
 	xmlFreeDoc (doc);
 	fprintf (stderr, "--- Internals ---\n");
 	dump_internals (tree, BNODE (node));
@@ -443,8 +445,6 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 	same = identical (tree, data->id, old_data->id);
 
 	g_assert (data->id);
-/*	if (!data->id)
-	same = TRUE;*/
 
 	override = !same && !transparent;
 
@@ -470,7 +470,7 @@ override_node_with (BonoboUIXml *tree, BonoboUINode *old, BonoboUINode *new)
 
  	/* This code doesn't work right with opaque BonoboUINode object */
  	if (bonobo_ui_node_children (new))
- 		merge (tree, old, (BonoboUINode**)&XML_NODE (new)->childs);
+ 		merge (tree, old, (BonoboUINode**)&XML_NODE (new)->xmlChildrenNode);
 
 	move_children (old, new);
 
@@ -495,7 +495,6 @@ reinstate_old_node (BonoboUIXml *tree, BonoboUINode *node)
 
 	g_return_if_fail (data != NULL);
 
- 	/* Mark tree as dirty */
 	if (data->overridden) { /* Something to re-instate */
 		BonoboUIXmlData *old_data;
 
