@@ -39,7 +39,7 @@ static GnomeCanvasItemClass *parent_class = NULL;
 /* The arguments we take */
 enum {
 	ARG_0,
-	ARG_EMBEDDABLE_DATA,
+	ARG_BONOBO_OBJECT_DATA,
 	/*	ARG_HEIGHT*/
 };
 
@@ -79,8 +79,8 @@ item_audio_class_init (ItemAudioClass *klass)
 
   parent_class = gtk_type_class (gnome_canvas_item_get_type ());
   
-  gtk_object_add_arg_type ("ItemAudio::EmbeddableData", GTK_TYPE_POINTER, 
-			   GTK_ARG_WRITABLE, ARG_EMBEDDABLE_DATA); 
+  gtk_object_add_arg_type ("ItemAudio::BonoboObjectData", GTK_TYPE_POINTER, 
+			   GTK_ARG_WRITABLE, ARG_BONOBO_OBJECT_DATA); 
   /*  gtk_object_add_arg_type ("ItemAudio::height", GTK_TYPE_DOUBLE, 
       GTK_ARG_READWRITE, ARG_HEIGHT);*/
  
@@ -100,7 +100,7 @@ item_audio_class_init (ItemAudioClass *klass)
 static void
 item_audio_init (ItemAudio *audio)
 {
-  audio->embeddable_data = NULL;
+  audio->bonobo_object_data = NULL;
   audio->height   = 1.0;
 }
 
@@ -113,9 +113,9 @@ item_audio_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int
   
   item->x1 = 0;
   item->y1 = 0;
-  if ( item_audio->embeddable_data )
+  if ( item_audio->bonobo_object_data )
     {
-      item->x2 = item_audio->embeddable_data->sound_len;
+      item->x2 = item_audio->bonobo_object_data->sound_len;
     }
   else item->x2 = 0;
   item->y2 = 256;
@@ -128,13 +128,13 @@ item_audio_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
 {
   ItemAudio *item_audio = ITEM_AUDIO (item);
   int i;
-  if( item_audio->embeddable_data && ( x + width > item_audio->embeddable_data->sound_len ) )
+  if( item_audio->bonobo_object_data && ( x + width > item_audio->bonobo_object_data->sound_len ) )
     {
-      width = item_audio->embeddable_data->sound_len - x;
+      width = item_audio->bonobo_object_data->sound_len - x;
     }
 
   gdk_draw_rectangle( drawable, item_audio->bg_gc, TRUE, 0, MAX( 0, -y ), width, MIN( height - MAX( 0, -y ), 256 ) );
-  if ( item_audio->embeddable_data && item_audio->embeddable_data->sound )
+  if ( item_audio->bonobo_object_data && item_audio->bonobo_object_data->sound )
     {
       for( i = x; i < x + width; i++ )
 	{
@@ -142,10 +142,10 @@ item_audio_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int
              state.  This should probably be improved in later
              versions.  Eventually, the data will have to be converted
              as you send it across for speed reasons. */
-	  if ( ((unsigned char *) item_audio->embeddable_data->sound)[i] < 128 )
-	    gdk_draw_point( drawable, item_audio->gc, i - x, ((unsigned char *) item_audio->embeddable_data->sound)[i] - y );
+	  if ( ((unsigned char *) item_audio->bonobo_object_data->sound)[i] < 128 )
+	    gdk_draw_point( drawable, item_audio->gc, i - x, ((unsigned char *) item_audio->bonobo_object_data->sound)[i] - y );
 	  else
-	    gdk_draw_point( drawable, item_audio->gc, i - x, 384 - ((unsigned char *) item_audio->embeddable_data->sound)[i] - y );
+	    gdk_draw_point( drawable, item_audio->gc, i - x, 384 - ((unsigned char *) item_audio->bonobo_object_data->sound)[i] - y );
 	}
     }
 }
@@ -174,8 +174,8 @@ item_audio_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	item_audio = ITEM_AUDIO (o);
 	
 	switch (arg_id){
-	case ARG_EMBEDDABLE_DATA:
-	  item_audio->embeddable_data = GTK_VALUE_POINTER (*arg);
+	case ARG_BONOBO_OBJECT_DATA:
+	  item_audio->bonobo_object_data = GTK_VALUE_POINTER (*arg);
 	  gnome_canvas_item_request_update (item);
 	  break;
 	  /*	case ARG_HEIGHT:
