@@ -356,6 +356,9 @@ create_control_menus (bonobo_object_data_t *bonobo_object_data)
 	 */
 	bonobo_object_release_unref (remote_uic, NULL);
 
+#undef BONOBO_TEXT_PLAIN_TEST_UI_HANDLER
+
+#ifdef BONOBO_TEXT_PLAIN_TEST_UI_HANDLER
 	parent = bonobo_ui_util_new_menu (TRUE, "text-plain", "_text-plain",
 					  "text-plain component", NULL);
 	node = bonobo_ui_util_new_menu (FALSE, "ClearText", _("_Clear Text"),
@@ -368,6 +371,7 @@ create_control_menus (bonobo_object_data_t *bonobo_object_data)
 				      verb_ClearText_cb, bonobo_object_data);
 
 	bonobo_ui_component_set_tree (bonobo_object_data->uic, "/menu", parent, NULL);
+#endif
 }
 
 static void
