@@ -58,6 +58,9 @@ extern "C" {
 #define EFS_FDEL        '/'
 #define EFS_FILE_ID  "%EFS"
 
+#define EFS_MIME_DIR  "x-directory/normal"
+#define EFS_MIME_DATA "application/octet-stream"
+
 typedef gchar *(*EFSPassFunc) (const gchar *filename, gboolean new);
 
 typedef struct _EFSNode EFSNode; /* File or Directory */
@@ -132,6 +135,7 @@ EFSResult    efs_node_open      (EFSNode **node, EFSDir *parent,
 				 const char *path, gint flags, gint type);
 EFSResult    efs_node_close     (EFSNode *node);
 EFSResult    efs_node_stat      (EFSNode *node, EFSStat *stat);
+gboolean     efs_node_equal     (EFSNode *node1, EFSNode *node2);
 EFSResult    efs_type_set       (EFSNode *node, guint32 type);
 EFSResult    efs_type_get       (EFSNode *node, guint32 *type);
 
