@@ -48,25 +48,25 @@ bonobo_moniker_factory (BonoboGenericFactory *this,
 
 	if (!strcmp (
 		object_id,
-		"OAFIID:FileMoniker:50425b-8309-45c5-8e08-7a14c2602438"))
+		"OAFIID:Bonobo_Moniker_File"))
 
 		moniker = gtk_type_new (bonobo_moniker_file_get_type ());
 
 	else if (!strcmp (
 		object_id,
-		"OAFIID:ItemMoniker:42d4d657-3be0-4e1a-9c1b-16e8da332e05"))
+		"OAFIID:Bonobo_Moniker_Item"))
 
 		moniker = gtk_type_new (bonobo_moniker_item_get_type ());
 	
 	else if (!strcmp (
 		object_id,
-		"OAFIID:OafMoniker:f7fd21cb-4aa9-4802-83e0-d82eabc983a8"))
+		"OAFIID:Bonobo_Moniker_Oaf"))
 
 		moniker = gtk_type_new (bonobo_moniker_oaf_get_type ());
 
 	else if (!strcmp (
 		object_id,
-		"OAFIID:NewMoniker:4ebfc80c-95f9-4f66-acfb-1a26b2d04cd4"))
+		"OAFIID:Bonobo_Moniker_New"))
 
 		moniker = gtk_type_new (bonobo_moniker_new_get_type ());
 
@@ -75,7 +75,7 @@ bonobo_moniker_factory (BonoboGenericFactory *this,
  *
  *	else if (!strcmp (
  *		object_id,
- *		"OAFIID:QueryMoniker:fb7f1678-9341-4749-9c5c-c3bb7b93abc1"))
+ *		"OAFIID:Bonobo_Moniker_Query"))
  *		
  *		moniker = gtk_type_new (bonobo_moniker_query_get_type ());
  */
@@ -126,7 +126,7 @@ main (int argc, char *argv [])
 		g_error (_("I could not initialize Bonobo"));
 
 	std_factory = bonobo_generic_factory_new_multi (
-		"OAFIID:MonikerFactory:2a80cf53-0daf-4e94-aac5-b01fbb8e0977",
+		"OAFIID:Bonobo_Moniker_stdFactory",
 		bonobo_moniker_factory, NULL);	
 
 	bonobo_main ();
