@@ -1,4 +1,4 @@
-/* $Id: bonobo-hello.c,v 1.10 2000/08/12 02:35:28 mmeeks Exp $ */
+/* $Id: bonobo-hello.c,v 1.12 2000/12/04 20:02:12 joeshaw Exp $ */
 /*
   Bonobo-Hello Copyright (C) 2000 RDI Gerg <cactus@cactus.rulez.org>
   
@@ -45,7 +45,7 @@ hello_bonobo_destroy (BonoboEmbeddable *embeddable,
 }
 
 static BonoboObject*
-hello_embeddable_factory (BonoboEmbeddableFactory *f, gpointer data)
+hello_embeddable_factory (BonoboGenericFactory *f, gpointer data)
 {
 	HelloBonoboEmbeddable *embeddable;
 
@@ -69,7 +69,7 @@ static void
 hello_bonobo_init (void)
 {
 	factory =
-		bonobo_embeddable_factory_new (
+		bonobo_generic_factory_new (
 			"OAFIID:bonobo-hello-factory:413433d0-c643-4618-9c3e-2c99f4d1b2a0",
 			hello_embeddable_factory, NULL);
 	if (!factory)
