@@ -1,4 +1,4 @@
-/* $Id: component.c,v 1.16 2000/10/19 08:44:34 dietmar Exp $ */
+/* $Id: component.c,v 1.17 2000/12/11 23:11:42 michael Exp $ */
 
 #include "component.h"
 #include "embeddable-io.h"
@@ -103,7 +103,7 @@ static void
 component_user_context_cb (BonoboViewFrame  *view_frame,
 			   SampleClientSite *site)
 {
-	g_warning ("We need some standardized verb stuff here...");
+	g_warning ("We need something exciting here ...");
 }
 
 void
