@@ -10,6 +10,8 @@
 
 poptContext ctx;
 
+#define ASYNC_MONIKERS
+
 void
 sample_app_exit (SampleApp *app)
 {
@@ -40,7 +42,7 @@ sample_app_create (void)
 
 	/* Create widgets */
 	app_widget = app->app = bonobo_window_new ("sample-container",
-						_("Sample Bonobo container"));
+						   _("Sample Bonobo container"));
 
 	app->box = gtk_vbox_new (FALSE, 10);
 
@@ -119,20 +121,89 @@ sample_app_add_component (SampleApp *app,
 	return sample_app_add_embeddable (app, server, object_id);
 }
 
-typedef struct {
-	SampleApp *app;
-	const char **startup_files;
-} setup_data_t;
-
-static Bonobo_Moniker
-make_moniker (const char *name)
+static void
+do_add_cb (Bonobo_Unknown     embeddable,
+	   CORBA_Environment *ev,
+	   gpointer           user_data)
 {
-	Bonobo_Moniker      moniker;
-	CORBA_Environment   ev;
+	SampleApp         *app = user_data;
+	SampleClientSite  *site;
+
+	if (BONOBO_EX (ev)) {
+		g_warning ("Moniker resolve demarshal exception '%s'\n",
+			   bonobo_exception_get_text (ev));
+		return;
+	}
+
+	if (embeddable == CORBA_OBJECT_NIL) {
+		g_warning ("Failed to demarshal embeddable");
+		return;
+	}
+
+	site = sample_app_add_embeddable (
+		app, bonobo_object_client_from_corba (embeddable),
+		"Kippers");
+
+	if (!site)
+		g_warning ("Failed to add embeddable to app");
+}
+
+#ifdef ASYNC_MONIKERS
+static void
+add_moniker_async (SampleApp  *app,
+		   const char *name,
+		   const char *interface)
+{
+	CORBA_Environment ev;
 
 	CORBA_exception_init (&ev);
 
-	moniker = bonobo_moniker_client_new_from_name (name, &ev);
+	bonobo_get_object_async (name, interface, &ev, 5000, do_add_cb, app);
+
+	if (BONOBO_EX (&ev)) {
+		g_warning ("bonobo_get_object_async exception '%s'\n",
+			 bonobo_exception_get_text (&ev));
+		return;
+	}
+
+	CORBA_exception_free (&ev);
+}
+#else
+static void
+resolve_and_add (SampleApp *app, Bonobo_Moniker moniker, const char *interface)
+{
+	CORBA_Environment ev;
+	char             *name;
+	Bonobo_Unknown    object;
+
+	CORBA_exception_init (&ev);
+
+	object = bonobo_moniker_client_resolve_default (
+		moniker, interface, &ev);
+
+	do_add_cb (object, &ev, app);
+
+	name = bonobo_moniker_client_get_name (moniker, &ev);
+	g_print ("My moniker looks like '%s'\n", name);
+	CORBA_free (name);
+
+	bonobo_object_release_unref (moniker, &ev);
+}
+
+static Bonobo_Moniker
+make_moniker (const char *name, SampleApp *app)
+{
+	Bonobo_Moniker    moniker = CORBA_OBJECT_NIL;
+	CORBA_Environment ev;
+	Bonobo_ActivationContext context;
+
+	CORBA_exception_init (&ev);
+
+	context = bonobo_context_get ("Activation", &ev);
+	g_return_val_if_fail (context != CORBA_OBJECT_NIL, CORBA_OBJECT_NIL);
+		
+	moniker = Bonobo_ActivationContext_createFromName (context, name, &ev);
+
 	if (ev._major != CORBA_NO_EXCEPTION) {
 		g_warning ("Moniker new exception '%s'\n",
 			   bonobo_exception_get_text (&ev));
@@ -141,42 +212,12 @@ make_moniker (const char *name)
 	
 	return moniker;
 }
+#endif
 
-static void
-resolve_and_add (SampleApp *app, Bonobo_Moniker moniker, const char *interface)
-{
-	Bonobo_Embeddable embeddable;
-	SampleClientSite *site;
-	CORBA_Environment ev;
-	char             *name;
-
-	CORBA_exception_init (&ev);
-
-	embeddable = bonobo_moniker_client_resolve_default (
-		moniker, interface, &ev);
-
-	if (ev._major != CORBA_NO_EXCEPTION) {
-		g_warning ("Moniker resolve exception '%s'\n",
-			 bonobo_exception_get_text (&ev));
-		return;
-	}
-
-	name = bonobo_moniker_client_get_name (moniker, &ev);
-	g_print ("My moniker looks like '%s'\n", name);
-	
-	if (ev._major != CORBA_NO_EXCEPTION)
-		g_warning ("Moniker get name exception '%s'\n",
-			   bonobo_exception_get_text (&ev));
-
-	site = sample_app_add_embeddable (
-		app, bonobo_object_client_from_corba (embeddable),
-		name);
-
-	if (!site)
-		g_warning ("Failed to add embeddable to app");
-
-	bonobo_object_release_unref (moniker, &ev);
-}
+typedef struct {
+	SampleApp *app;
+	const char **startup_files;
+} setup_data_t;
 
 /*
  *  This is placed after the Bonobo main loop has started
@@ -193,15 +234,21 @@ final_setup (setup_data_t *sd)
 	}
 
 	if (g_getenv ("BONOBO_MONIKER_TEST")) {
-		Bonobo_Moniker moniker;
+#ifdef ASYNC_MONIKERS
+		add_moniker_async (sd->app, "file:/demo/a.jpeg", "IDL:Bonobo/Embeddable:1.0");
+#else
+		{
+			Bonobo_Moniker moniker;
+		
+			moniker = make_moniker ("file:/demo/a.jpeg", sd->app);
+			resolve_and_add (sd->app, moniker, "IDL:Bonobo/Embeddable:1.0");
+			bonobo_object_release_unref (moniker, NULL);
+		}
+#endif
 
-		moniker = make_moniker ("file:/demo/a.jpeg");
+/*		moniker = make_moniker ("OAFIID:bonobo_application-x-mines:804d34a8-57dd-428b-9c94-7aa3a8365230");
 		resolve_and_add (sd->app, moniker, "IDL:Bonobo/Embeddable:1.0");
-		bonobo_object_release_unref (moniker, NULL);
-
-		moniker = make_moniker ("OAFIID:bonobo_application-x-mines:804d34a8-57dd-428b-9c94-7aa3a8365230");
-		resolve_and_add (sd->app, moniker, "IDL:Bonobo/Embeddable:1.0");
-		bonobo_object_release_unref (moniker, NULL);
+		bonobo_object_release_unref (moniker, NULL);*/
 
 /*		moniker = make_moniker ("query:(bonobo:supported_mime_types.has ('image/x-png'))");
 		resolve_and_add (sd->app, moniker, "IDL:Bonobo/Embeddable:1.0");
