@@ -10,13 +10,7 @@
 
 #include <config.h>
 #include <gnome.h>
-
-#if USING_OAF
 #include <liboaf/liboaf.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
-
 #include <bonobo.h>
 
 #include "bonobo-clock-control.h"
@@ -29,17 +23,11 @@ static void
 init_bonobo (int argc, char **argv)
 {
 
-#if USING_OAF
         gnome_init_with_popt_table("sample-control-factory", "0.0",
 				   argc, argv,
 				   oaf_popt_options, 0, NULL); 
 	orb = oaf_init (argc, argv);
-#else
-	gnome_CORBA_init_with_popt_table (
-		"sample-control-factory", "0.0",
-		&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
-	orb = gnome_CORBA_ORB ();
-#endif
+
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
 		g_error (_("Could not initialize Bonobo"));
 }
@@ -48,6 +36,9 @@ int
 main (int argc, char **argv)
 {
 	CORBA_exception_init (&ev);
+	
+	/* Encorage -lefence to play ball */
+	{ char *tmp = malloc (4); if (tmp) free (tmp); }
 
 	init_bonobo (argc, argv);
 
